import olefile


def extract_streams(file_path):
    if not olefile.isOleFile(file_path):
        raise ValueError("The provided file is not a valid .doc file.")

    with olefile.OleFileIO(file_path) as ole:
        streams = ole.listdir()

        if ["WordDocument"] in streams:
            data = ole.openstream("WordDocument").read()
            return data
        else:
            raise ValueError("WordDocument stream not found.")


def extraxt_txt(file_path):
    data = extract_streams(file_path)
    decoded_text = data.decode("utf-16-le", errors="ignore").replace("\r", "\n")
    return "".join(i for i in decoded_text.split("\00") if i and "\n" in i)



from setuptools import setup, find_packages

setup(
    name="edoc",
    version="1.0.1",
    description=("Extract text from doc"),
    long_description=open("README.rst").read(),
    author="twfb",
    author_email="twfb@hotmail.com",
    maintainer="twfb",
    maintainer_email="twfb@hotmail.com",
    license="BSD License",
    packages=find_packages(),
    platforms=["all"],
    include_package_data=True,
    url="https://github.com/twfb/edoc",
    install_requires=["olefile"],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Operating System :: OS Independent",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: Implementation",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Topic :: Software Development :: Libraries",
    ],
),
